Index: src/services/PlaylistService.js
===================================================================
--- src/services/PlaylistService.js	(revision 7bc636b391c66ac399c33e54f7173a022c6a3cbd)
+++ src/services/PlaylistService.js	(revision 353c39c44a0345eccc323b017eed75c29297b9c3)
@@ -77,10 +77,10 @@
    * Returns null if the playlist doesn't exist.
    *
-   * `signUrl` is an optional callback that takes a media filename and returns
-   * a (possibly signed) URL. If not provided, tracks come back with no `url`
-   * and the caller has to resolve them. The render pipeline in posts.js
-   * always passes signUrl.
-   */
-  static get(siteId, id, signUrl) {
+   * `urlFor` is an optional callback that takes a media filename and returns
+   * its stream URL. If not provided, tracks come back with no `url` and the
+   * caller has to resolve them. The render pipeline in posts.js always passes
+   * urlFor.
+   */
+  static get(siteId, id, urlFor) {
     id = this.normalizeId(id);
     if (!id) return null;
@@ -117,5 +117,5 @@
           cover: t.cover_url || p.cover_url || '',
           duration: t.duration || 0,
-          url: signUrl ? signUrl(t.filename).url : null,
+          url: urlFor ? urlFor(t.filename) : null,
         })),
     };
